import * as React from "react";
import AppBar from "@mui/material/AppBar";
import Box from "@mui/material/Box";
import CssBaseline from "@mui/material/CssBaseline";
import Divider from "@mui/material/Divider";
import Drawer from "@mui/material/Drawer";
import IconButton from "@mui/material/IconButton";
import InboxIcon from "@mui/icons-material/MoveToInbox";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemIcon from "@mui/material/ListItemIcon";
import ListItemText from "@mui/material/ListItemText";
import MailIcon from "@mui/icons-material/Mail";
import MenuIcon from "@mui/icons-material/Menu";
import Toolbar from "@mui/material/Toolbar";
import Typography from "@mui/material/Typography";
import { InputAdornment, TextField } from "@mui/material";
import Grid from "@mui/material/Grid";
import Container from "@mui/material/Container";
import Paper from "@mui/material/Paper";
import CheckIcon from "@mui/icons-material/Check";
import TypeTable from "../../components/tables/TypeTable";
import SignTable from "../../components/tables/SignTable";
import { useEffect, useState } from "react";
import axios from "axios";
import CheckCircleIcon from "@mui/icons-material/CheckCircle";

function SettingsGeneral() {
  const [settings, setSettings] = useState([]);

  useEffect(() => {
    axios("http://localhost:8000/api/settings/", {
      method: "GET",
      withCredentials: true,
    }).then((res) => {
      setSettings(res.data);
    });
  }, []);

  function handleTextFieldChange(e, index) {
    let updatedSettings = [...settings];
    updatedSettings[index].value = e.target.value;

    setSettings(updatedSettings);
  }

  function updateSettingItem(setting) {
    const headers = {
      "Content-Type": "application/json",
    };
    axios("http://localhost:8000/api/settings/" + setting.setting_id + "/", {
      headers: headers,
      method: "PUT",
      withCredentials: true,
      data: setting,
    });
  }

  return (
    <Box>
      {settings.map((setting, index) => (
        <Box
          sx={{
            display: "flex",
            alignItems: "center",
            mt: "55px",
            ml: "15px",
          }}
          key={index}
        >
          <Typography align="right" width="30%" mr={2}>
            {setting.item}
          </Typography>
          <Box sx={{ width: "70%" }}>
            <TextField
              type="number"
              sx={{ width: "60%" }}
              value={setting.value}
              key={index}
              defaultValue={1}
              onChange={(e) => handleTextFieldChange(e, index)}
              InputProps={{
                endAdornment: (
                  <InputAdornment position="end">
                    <IconButton
                      color="primary"
                      onClick={(e) => updateSettingItem(setting)}
                    >
                      <CheckCircleIcon />
                    </IconButton>
                  </InputAdornment>
                ),
              }}
              id="username"
            />
          </Box>
        </Box>
      ))}
      <Grid container spacing={0} sx={{ bt: "50px" }}>
        <Grid item xs={12} md={6}>
          <TypeTable />
        </Grid>
        <Grid item xs={12} md={6}>
          <SignTable />
        </Grid>
      </Grid>
    </Box>
  );
}

export default SettingsGeneral;
